@@ -32,7 +32,7 @@ class HeadlessPromptParams(FrozenModel):
     """LLM model parameters for a prompt."""
 
     version: str
-    params: Dict[str, Any]
+    params: Optional[Dict[str, Any]]
 
 
 class HeadlessPromptTemplate(FrozenModel):
@@ -80,7 +80,9 @@ class WeightedMinorVersion(
 
 
 class PromptMinorVersion(FrozenModel):
-    version: Union[Enum, List[WeightedMinorVersion]]
+    # need to do more research here, WeightedMinorVersion requires generics but we don't care what it is in this case,
+    # just that it's an instance of WeightedMinorVersion.
+    version: Union[Enum, List[WeightedMinorVersion]]  # type: ignore
 
     @property
     def str_version(self) -> Optional[str]:
@@ -89,7 +91,7 @@ class PromptMinorVersion(FrozenModel):
         return str(self.version.value)
 
     @property
-    def weighted_versions(self) -> Optional[List[WeightedMinorVersion]]:
+    def weighted_versions(self) -> Optional[List[WeightedMinorVersion]]:  # type: ignore
         if isinstance(self.version, list):
             return self.version
         return None
@@ -115,6 +117,8 @@ class PromptMinorVersion(FrozenModel):
         elif str_version := self.str_version:
             return str_version
 
+        raise RuntimeError("Minor version should either be a string or a list of weighted versions.")
+
 
 class AutogeneratePromptConfig(FrozenModel):
     id: str
